.. image:: ./flippers.png
   :align: center
   :width: 300
   :alt: flippers logo.


Welcome to flippers!
===================================

**flippers** is a Python library for weak supervision. 
With ``flippers``, you can leverage domain knowledge and heuristics
to generate high-quality labels for your training data.

``flippers`` is built to be an alternative and improvement to the now archived ``Snorkel`` library with the following goals:

- Lightweight and easy to use.
- Fast and scalable.
- Better accuracy and calibration of the label model.
- Easy integratation with any machine learning pipeline.
- Strong documentation and support.

For more details, please refer to the following resources:

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   Quick Start <pages/quickstart>
   API Reference <reference/flippers>
